"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/preload.ts
var _unplugin = require('unplugin');
var preload = _unplugin.createUnplugin.call(void 0, (options, meta) => {
  return {
    name: "unplugin-auto-expose-preload",
    renderChunk(code, info) {
      if (!info.isEntry) {
        return;
      }
      code += "\nconst {contextBridge} = require('electron');\n";
      for (const exp of info.exports) {
        code += `;
contextBridge.exposeInMainWorld('__electron_preload__${exp}', exports.${exp});
`;
      }
      return code;
    }
  };
});

// src/renderer.ts


// src/scanExports.ts
var _promises = require('fs/promises');
var _mlly = require('mlly');
async function scanExports(filepath) {
  const imports = [];
  const code = await _promises.readFile.call(void 0, filepath, "utf-8");
  const exports = _mlly.findExports.call(void 0, code);
  const defaultExport = exports.find((i) => i.type === "default");
  if (defaultExport) {
    imports.push({ name: "default", as: "default", from: filepath });
  }
  for (const exp of exports) {
    if (exp.type === "named") {
      for (const name of exp.names) {
        imports.push({ name, as: name, from: filepath });
      }
    } else if (exp.type === "declaration") {
      if (exp.name) {
        imports.push({ name: exp.name, as: exp.name, from: filepath });
      }
    }
  }
  return imports;
}

// src/renderer.ts
var renderer = _unplugin.createUnplugin.call(void 0, (options) => {
  const virtualModuleId = "#preload";
  const resolvedVirtualModuleId = "\0" + virtualModuleId.replace("#", "@");
  return {
    name: "unplugin-auto-expose-renderer",
    resolveId(source) {
      if (source === virtualModuleId) {
        return resolvedVirtualModuleId;
      }
    },
    async load(id) {
      if (id === resolvedVirtualModuleId) {
        const exp = await scanExports(options.preloadEntry);
        const names = new Set(exp.map((e) => e.as === "src" ? "default" : e.as));
        return [...names].reduce((code, name) => {
          return code + `export ${name === "default" ? "default" : `const ${name} =`} globalThis.__electron_preload__${name};
`;
        }, "");
      }
    }
  };
});



exports.preload = preload; exports.renderer = renderer;
